import 'package:dio/dio.dart';
import 'package:progamification/src/constants/service_urls.dart';
import 'package:progamification/src/environments/env.dart';
import 'package:progamification/src/utilities/http_client.dart';

class AxiosServices {
  Dio getServiceInstance() {
    return getHttpClient(redeemBaseUrl);
  }
}

class RedeemService {
  Dio httpClientRedeem = AxiosServices().getServiceInstance();

  Future<dynamic> getRedeemRulesByApplication(String applicationId) {
    return httpClientRedeem.get(
      ServiceUrls.getRedeemRulesByApplication(applicationId),
    );
  }

  Future<dynamic> getTransactionHistory(String userId, String appId) async {
    Map<String, dynamic> bodyMap = {
      'gamificationUserId': userId,
      'gamificationApplicationId': appId,
    };

    Response response = await httpClientRedeem.post(
      ServiceUrls.getMyOrders,
      data: bodyMap,
      options: Options(
        headers: bodyMap,
      ),
    );

    return response;
  }

  Future<dynamic> getWalletBalance(String appId, String userId) async {
    Map<String, dynamic> bodyMap = {
      'gamificationUserId': userId,
      'gamificationApplicationId': appId,
    };

    Response response = await httpClientRedeem.post(
      ServiceUrls.getWalletBalance,
      data: bodyMap,
      options: Options(
        headers: bodyMap,
      ),
    );

    return response;
  }

  Future<dynamic> getOrders(String userId, String appId) async {
    Map<String, dynamic> bodyMap = {
      'gamificationUserId': userId,
      'gamificationApplicationId': appId,
    };

    Response response = await httpClientRedeem.post(
      ServiceUrls.getOrders,
      data: bodyMap,
      options: Options(
        headers: bodyMap,
      ),
    );

    return response;
  }

  Future<dynamic> redeemProduct(dynamic redeemableProduct) async {
    Response response = await httpClientRedeem.post(
      ServiceUrls.redeemProduct,
      data: redeemableProduct,
    );

    return response;
  }
}
