import 'package:flutter/material.dart';
import 'package:get/get.dart' hide Progress;
import 'package:progamification/src/controllers/leader_board.dart';
import 'package:progamification/src/models/leader_board.dart';
import 'package:progamification/src/widgets/coins.dart';
import 'package:progamification/src/widgets/order.dart';
import 'package:progamification/src/widgets/progress.dart';
import 'package:progamification/src/widgets/redeem.dart';
import 'package:progamification/src/widgets/rewards.dart';

class Achievements extends StatefulWidget {
  final String userId, appId;
  final LeaderBoardModel currentUser;

  const Achievements(
      {super.key,
      required this.appId,
      required this.userId,
      required this.currentUser});

  @override
  State<Achievements> createState() => _AchievementsState();
}

class _AchievementsState extends State<Achievements> {
  LeaderBoardController leaderBoardController =
      Get.find<LeaderBoardController>();
  @override
  Widget build(BuildContext context) {
    return Container(
        decoration: const BoxDecoration(
          color: Colors.white,
        ),
        child: FutureBuilder<Map<String, dynamic>>(
            future:
                leaderBoardController.getRewards(widget.userId, widget.appId),
            builder: (context, snapshot) {
              return SingleChildScrollView(
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment
                      .start, 
                  children: [
                    Progress(
                      snapshot: snapshot,
                      currentUser: widget.currentUser,
                    ),
                    Container(
                      padding: EdgeInsets.all(8.0),
                      child: Row(
                        children: [
                          Expanded(
                              flex: 1,
                              child: Coin(
                                  userId: widget.userId,
                                  applicationId: widget.appId)),
                          SizedBox(width: 16),
                          Expanded(
                            flex: 1,
                            child: Redeem(
                              userId: widget.userId,
                              applicationId: widget.appId,
                            ),
                          ),
                        ],
                      ),
                    ),
                    Container(
                      margin: EdgeInsets.only(right: 16),
                      padding: EdgeInsets.all(8.0),
                      child: FractionallySizedBox(
                        widthFactor: 0.5,
                        alignment: Alignment.centerLeft,
                        child: Order(
                          userId: widget.userId,
                          applicationId: widget.appId,
                        ),
                      ),
                    ),
                    Rewards(snapshot: snapshot),
                  ],
                ),
              );
            }));
  }
}
