import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:get/get_core/src/get_main.dart';
import 'package:progamification/src/environments/env.dart';
import 'package:progamification/src/services/redeem.service.dart';
import 'package:progamification/src/services/sas_token.service.dart';
import 'package:progamification/src/widgets/wallet.dart';

class Coin extends StatefulWidget {
  final String userId;
  final String applicationId;

  Coin({required this.userId, required this.applicationId});

  @override
  _CoinState createState() => _CoinState();
}

class _CoinState extends State<Coin> {
  SasTokenService sasTokenService = Get.find<SasTokenService>();
  String sasToken = "";
  late Map<String, dynamic> userWalletBalance = {};
  bool _isTapped = false;
  @override
  void initState() {
    super.initState();
    sasTokenService.getSasToken().then((value) {
      setState(() {
        sasToken = value.toString();
      });
    });
    _getWalletBalance(widget.userId, widget.applicationId);
  }

  Future<void> _getWalletBalance(String userId, String appId) async {
    try {
      await Get.find<RedeemService>()
          .getWalletBalance(appId, userId)
          .then((data) async {
        setState(() {
          userWalletBalance =
              Map<String, dynamic>.from(data.data['balance'][0]);
        });
      });
    } catch (e) {}
  }

  void _handleOpenPopup(BuildContext context) {
    setState(() {
      _isTapped = true;
    });

    Navigator.of(context)
        .push(
      MaterialPageRoute(
        builder: (context) => Wallet(
          userId: widget.userId,
          applicationId: widget.applicationId,
        ),
      ),
    )
        .then((value) {
      setState(() {
        _isTapped = false;
      });
    });
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () => _isTapped ? null : _handleOpenPopup(context),
      child: Container(
        margin: EdgeInsets.all(8),
        padding: EdgeInsets.all(12),
        decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(8),
          color: Color(0xFFFFF6E6),
          boxShadow: [
            BoxShadow(
              color: Colors.grey.withOpacity(0.5),
              spreadRadius: 2,
              blurRadius: 5,
              offset: Offset(0, 3),
            ),
          ],
        ),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Text(
              "Wallet",
              style: TextStyle(fontSize: 16, fontWeight: FontWeight.bold),
            ),
            SizedBox(height: 8),
            Container(
              child: userWalletBalance.isNotEmpty
                  ? Row(
                      children: [
                        Padding(
                          padding: const EdgeInsets.all(8.0),
                          child: Image.network(
                            userWalletBalance['imageUrl'] + sasToken,
                            width: 35,
                            height: 35,
                          ),
                        ),
                        Text(userWalletBalance['balance'].toString())
                      ],
                    )
                  : Row(
                      children: [
                        Padding(
                          padding: const EdgeInsets.all(8.0),
                          child: Image.network(
                            blobUrl + 'Coins.png',
                            width: 35,
                            height: 35,
                          ),
                        ),
                        Text("0")
                      ],
                    ),
            ),
            SizedBox(height: 8),
            Row(
              children: [
                Text(
                  "Go to Wallet",
                  style: TextStyle(fontSize: 10, color: Color(0xFF333333)),
                ),
                Icon(Icons.arrow_forward, size: 15, color: Color(0xFF333333)),
              ],
            ),
          ],
        ),
      ),
    );
  }
}
