import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:get/get_core/src/get_main.dart';
import 'package:progamification/src/services/redeem.service.dart';
import 'package:progamification/src/widgets/ordered_product.dart';

class ListOrderProduct extends StatefulWidget {
  final String userId;
  final String applicationId;

  const ListOrderProduct({
    Key? key,
    required this.userId,
    required this.applicationId,
  }) : super(key: key);

  @override
  _ListOrderProductState createState() => _ListOrderProductState();
}

class _ListOrderProductState extends State<ListOrderProduct> {
  late List<Map<String, dynamic>> listOrders;
  late bool isLoading;

  @override
  void initState() {
    super.initState();
    listOrders = [];
    isLoading = true;
    _getTransactionHistory(widget.userId, widget.applicationId);
  }

  Future<void> _getTransactionHistory(String userId, String appId) async {
    setState(() {
      isLoading = true;
    });
    try {
      await Get.find<RedeemService>()
          .getTransactionHistory(userId, appId)
          .then((data) async {
        setState(() {
          listOrders = List<Map<String, dynamic>>.from(data.data).toList();
          isLoading = false;
        });
      });
    } catch (e) {
      setState(() {
        isLoading = false;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(
        backgroundColor: Colors.white,
        automaticallyImplyLeading: false,
        toolbarHeight: kTextTabBarHeight,
        flexibleSpace: Get.width < 600
            ? Row(
                crossAxisAlignment: CrossAxisAlignment.center,
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  Container(
                    margin: const EdgeInsets.only(top: 45.0, left: 20),
                    child: Text(
                      "My Orders",
                      style:
                          TextStyle(fontSize: 28, fontWeight: FontWeight.bold),
                    ),
                  ),
                  Spacer(),
                  Row(
                    children: [
                      Container(
                        decoration: BoxDecoration(
                          borderRadius: BorderRadius.circular(50),
                          border: Border.all(color: Colors.grey[400]!),
                        ),
                        margin: const EdgeInsets.only(
                            top: 45.0, left: 20, right: 10),
                        child: ClipRRect(
                          borderRadius: BorderRadius.circular(30),
                          child: FloatingActionButton(
                            onPressed: (() => Navigator.pop(context)),
                            elevation: 0,
                            backgroundColor: Colors.grey[100],
                            child: const Icon(
                              Icons.close,
                              color: Colors.black,
                            ),
                          ),
                        ),
                      ),
                    ],
                  ),
                ],
              )
            : null,
      ),
      body: Padding(
        padding: const EdgeInsets.only(top: 18.0, bottom: 18.0),
        child: isLoading
            ? Center(
                child: CircularProgressIndicator(),
              )
            : Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Expanded(
                    child: ListView.builder(
                      itemCount: listOrders.length,
                      itemBuilder: (context, index) {
                        final product = listOrders[index];
                        return Padding(
                          padding: EdgeInsets.symmetric(vertical: 14.0),
                          child: Container(
                            margin: EdgeInsets.only(left: 10, right: 10),
                            decoration: BoxDecoration(
                              border: Border(
                                bottom: BorderSide(
                                    color: Colors.grey[300]!, width: 1.0),
                              ),
                            ),
                            child: Padding(
                              padding: const EdgeInsets.only(bottom: 19.0),
                              child: ListTile(
                                leading: SizedBox(
                                  width: 100,
                                  height: 200,
                                  child: Image.network(
                                    product['productImageUrl'],
                                    fit: BoxFit.fill,
                                  ),
                                ),
                                title: Column(
                                  children: [
                                    Text(
                                      product['productName'],
                                      textAlign: TextAlign.start,
                                    ),
                                    ElevatedButton(
                                      onPressed: () => Navigator.push(
                                        context,
                                        MaterialPageRoute(
                                          builder: (context) => OrderedProduct(
                                            userId: widget.userId,
                                            applicationId: widget.applicationId,
                                            product: product,
                                          ),
                                        ),
                                      ),
                                      child: Text(
                                        "View Order History",
                                        style: TextStyle(
                                            color: Colors.black, fontSize: 11),
                                      ),
                                    ),
                                  ],
                                ),
                                trailing: Column(
                                  crossAxisAlignment: CrossAxisAlignment.start,
                                  children: [
                                    Text(
                                      product['orderStatus'],
                                      textAlign: TextAlign.start,
                                      style: TextStyle(fontSize: 10),
                                    ),
                                  ],
                                ),
                              ),
                            ),
                          ),
                        );
                      },
                    ),
                  ),
                ],
              ),
      ),
    );
  }
}
