import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:progamification/src/services/redeem.service.dart';
import 'package:progamification/src/services/sas_token.service.dart';
import 'package:progamification/src/widgets/redeem_product.dart';
import 'package:progamification/src/widgets/wallet_balance.dart';

class ListRedemableProduct extends StatefulWidget {
  final String userId;
  final String applicationId;

  const ListRedemableProduct({
    Key? key,
    required this.userId,
    required this.applicationId,
  }) : super(key: key);

  @override
  State<ListRedemableProduct> createState() => _ListRedemableProductState();
}

class _ListRedemableProductState extends State<ListRedemableProduct> {
  late List<Map<String, dynamic>> products;
  SasTokenService sasTokenService = Get.find<SasTokenService>();
  late bool isLoading;
  String sasToken = "";
  @override
  void initState() {
    super.initState();
    sasTokenService.getSasToken().then((value) {
      setState(() {
        sasToken = value.toString();
      });
    });

    products = [];
    isLoading = true;
    _getRedeemableProducts(widget.applicationId);
  }

  Future<void> _getRedeemableProducts(String applicationId) async {
    setState(() {
      isLoading = true;
    });
    try {
      await Get.find<RedeemService>()
          .getRedeemRulesByApplication(applicationId)
          .then((data) async {
        setState(() {
          products = List<Map<String, dynamic>>.from(data.data).toList();
          isLoading = false;
        });
      });
    } catch (e) {
      setState(() {
        isLoading = false;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(
        backgroundColor: Colors.white,
        automaticallyImplyLeading: false,
        toolbarHeight: kTextTabBarHeight,
        flexibleSpace: Get.width < 600
            ? Row(
                crossAxisAlignment: CrossAxisAlignment.center,
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  Container(
                      margin: const EdgeInsets.only(top: 45.0, left: 20),
                      child: Text(
                        "Redeem",
                        style: TextStyle(
                            fontSize: 28, fontWeight: FontWeight.bold),
                      )),
                  Spacer(),
                  Row(
                    children: [
                      WalletBalance(
                        userId: widget.userId,
                        applicationId: widget.applicationId,
                      ),
                      Container(
                        decoration: BoxDecoration(
                          borderRadius: BorderRadius.circular(50),
                          border: Border.all(color: Colors.grey[400]!),
                        ),
                        margin: const EdgeInsets.only(
                            top: 45.0, left: 20, right: 10),
                        child: ClipRRect(
                          borderRadius: BorderRadius.circular(30),
                          child: FloatingActionButton(
                            onPressed: (() => Navigator.pop(context)),
                            elevation: 0,
                            backgroundColor: Colors.grey[100],
                            child: const Icon(
                              Icons.close,
                              color: Colors.black,
                            ),
                          ),
                        ),
                      ),
                    ],
                  ),
                ],
              )
            : null,
      ),
      body: SafeArea(
        child: Padding(
          padding: const EdgeInsets.only(top: 18.0, bottom: 18.0),
          child: Container(
            color: Colors.white,
            child: Column(
              children: [
                Expanded(
                    child: isLoading
                        ? Center(child: CircularProgressIndicator())
                        : products.isEmpty && sasToken.isNotEmpty
                            ? Center(child: Text("No products available"))
                            : SingleChildScrollView(
                                padding: EdgeInsets.all(14),
                                child: GridView.count(
                                  crossAxisCount: 2,
                                  mainAxisSpacing: 15,
                                  crossAxisSpacing: 15,
                                  shrinkWrap: true,
                                  physics: NeverScrollableScrollPhysics(),
                                  childAspectRatio: 0.8,
                                  children: products.map((product) {
                                    return SizedBox(
                                      child: GestureDetector(
                                        onTap: () {
                                          Navigator.push(
                                            context,
                                            MaterialPageRoute(
                                                builder: (context) =>
                                                    RedeemProduct(
                                                      userId: widget.userId,
                                                      applicationId:
                                                          widget.applicationId,
                                                      product: product,
                                                    )),
                                          );
                                        },
                                        child: Card(
                                          elevation: 2.0,
                                          child: Container(
                                            margin: EdgeInsets.all(10),
                                            decoration: BoxDecoration(
                                              borderRadius:
                                                  BorderRadius.circular(8),
                                            ),
                                            child: Column(
                                              children: [
                                                Padding(
                                                  padding:
                                                      const EdgeInsets.all(8.0),
                                                  child: Image.network(
                                                    product['productImageUrl'] +
                                                        sasToken,
                                                    width: double.infinity,
                                                    height: 70,
                                                    fit: BoxFit.fill,
                                                  ),
                                                ),
                                                Padding(
                                                  padding: const EdgeInsets
                                                      .symmetric(vertical: 8.0),
                                                  child: Text(
                                                    product['productName'],
                                                    style:
                                                        TextStyle(fontSize: 16),
                                                  ),
                                                ),
                                                Padding(
                                                    padding: const EdgeInsets
                                                        .symmetric(
                                                        vertical: 8.0),
                                                    child: sasToken.isNotEmpty
                                                        ? Row(
                                                            children: [
                                                              Image.network(
                                                                product['virtualMoneyImageUrl'] +
                                                                    sasToken,
                                                                width: 25,
                                                                height: 25,
                                                                fit: BoxFit
                                                                    .contain,
                                                              ),
                                                              Padding(
                                                                padding:
                                                                    const EdgeInsets
                                                                        .only(
                                                                        left:
                                                                            8.0),
                                                                child: Text(
                                                                  product['eligibleMoney']
                                                                      .toString(),
                                                                  style: TextStyle(
                                                                      fontSize:
                                                                          16),
                                                                ),
                                                              ),
                                                            ],
                                                          )
                                                        : SizedBox()),
                                              ],
                                            ),
                                          ),
                                        ),
                                      ),
                                    );
                                  }).toList(),
                                ),
                              )),
              ],
            ),
          ),
        ),
      ),
    );
  }
}
