import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:progamification/src/models/leader_board.dart';
import 'package:progamification/src/services/user_group.service.dart';
import 'package:progamification/src/widgets/leaderboard_table.dart';

class ListUserGroups extends StatefulWidget {
  final String userId;
  final String applicationId;

  final LeaderBoardModel currentUser;
  const ListUserGroups({
    Key? key,
    required this.currentUser,
    required this.userId,
    required this.applicationId,
  }) : super(key: key);

  @override
  State<ListUserGroups> createState() => _ListUserGroupsState();
}

class _ListUserGroupsState extends State<ListUserGroups> {
  late List<Map<String, dynamic>> userGroups;
  late bool isLoading;
  late bool isShowLocalLeaderBorad;
  String sasToken = "";
  String userGroup = "";
  var leaderBoardData = <LeaderBoardModel>[];
  @override
  void initState() {
    super.initState();
    isShowLocalLeaderBorad = false;
    userGroups = [];
    isLoading = true;
    _getUserGroupsByAppId(widget.userId, widget.applicationId);
  }

  Future<void> _getUserGroupsByAppId(String userId, String appId) async {
    setState(() {
      isLoading = true;
    });
    try {
      await Get.find<UserGroupService>()
          .getUserGroupByAppId(userId, appId)
          .then((data) async {
        setState(() {
          userGroups =
              List<Map<String, dynamic>>.from(data.data['data']).toList();
          isLoading = false;
        });
      });
    } catch (e) {
      setState(() {
        isLoading = false;
      });
    }
  }

  void onCloseLocalLeaderBoard() {
    setState(() {
      isShowLocalLeaderBorad = false;
    });
  }

  Future<void> _navigateToAnotherWidget(
      String userGroupId, String userGroupName) async {
    try {
      await Get.find<UserGroupService>()
          .getRankByUserGroupId(
              widget.applicationId, widget.userId, userGroupId)
          .then((data) async {
        dynamic boardData = data.data['data'];
        leaderBoardData = (boardData['Items'] as List)
            .map((e) => LeaderBoardModel.fromJson(e))
            .toList();
      });
    } catch (e) {}
    if (leaderBoardData.isNotEmpty) {
      isShowLocalLeaderBorad = true;
      setState(() {
        leaderBoardData = leaderBoardData;
        userGroup = userGroupName;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      height: MediaQuery.of(context).size.height,
      child: Scaffold(
        body: isLoading
            ? Center(
                child: CircularProgressIndicator(),
              )
            : !isShowLocalLeaderBorad
                ? Container(
                    child: ListView.builder(
                      itemCount: userGroups.length,
                      itemBuilder: (context, index) {
                        final group = userGroups[index];
                        return Padding(
                          padding: const EdgeInsets.all(2.0),
                          child: Padding(
                            padding: const EdgeInsets.all(8.0),
                            child: InkWell(
                              onTap: () {
                                _navigateToAnotherWidget(group['userGroupId'],
                                    group['userGroupName']);
                              },
                              child: Container(
                                decoration: BoxDecoration(
                                  border: Border.all(
                                    color: Color(0xFFff8725),
                                    width: 1.0,
                                  ),
                                  borderRadius: BorderRadius.circular(8.0),
                                ),
                                child: ListTile(
                                  leading: Text(
                                    "#" + group['rank'].toString(),
                                    style: TextStyle(
                                        fontWeight: FontWeight.w900,
                                        fontSize: 16),
                                  ),
                                  title: Text(group['userGroupName']),
                                  trailing: Icon(Icons.arrow_forward_ios),
                                ),
                              ),
                            ),
                          ),
                        );
                      },
                    ),
                  )
                : LeaderBoardTable(
                    currentUser: widget.currentUser,
                    leaderBoardData: leaderBoardData,
                    onCloseLocalLeaderBoard: onCloseLocalLeaderBoard,
                    userGroupName: userGroup,
                  ),
      ),
    );
  }
}
