import 'package:flutter/material.dart';
import 'package:progamification/src/constants/color_contants.dart';
import 'package:progamification/src/controllers/leader_board.dart';
import 'package:get/get.dart';
import 'package:progamification/src/models/leader_board.dart';
import 'package:progamification/src/services/sas_token.service.dart';
import 'package:progamification/src/services/storage.service.dart';
import 'package:google_fonts/google_fonts.dart';

import 'linear_progress_indicator.dart';

class Progress extends StatefulWidget {
  final AsyncSnapshot<Map<String, dynamic>>? snapshot;
  final LeaderBoardModel currentUser;

  const Progress({Key? key, required this.snapshot, required this.currentUser})
      : super(key: key);

  @override
  State<Progress> createState() => _ProgressState();
}

class _ProgressState extends State<Progress> {
  String level = "";
  var nextAchiveReward;
  LeaderBoardController leaderBoardController =
      Get.find<LeaderBoardController>();
  final GamificationStorageService storageService =
      Get.find<GamificationStorageService>();

  SasTokenService sasTokenService = Get.find<SasTokenService>();
  String sasToken = "";

  @override
  initState() {
    super.initState();
    sasTokenService.getSasToken().then((value) {
      setState(() {
        sasToken = value.toString();
      });
    });
  }

  TextStyle textStyle({Color fontColor = Colors.black}) => TextStyle(
      color: fontColor,
      fontSize: 18.0,
      fontFamily: GoogleFonts.plusJakartaSans().fontFamily,
      fontWeight: FontWeight.w600);

  @override
  Widget build(BuildContext context) {
    if (widget.snapshot!.hasData) {
      var points = widget.snapshot!.data!['points'] ?? 0;
      var progress = double.parse(widget.snapshot!.data!['progress'] ?? '0');
      var previousReward = widget.snapshot!.data!['previousReward'];
      var nextReward = widget.snapshot!.data!['nextReward'];
      level = widget.snapshot!.data!['level'].toString();
      setState(() {
        nextAchiveReward = nextReward!['score'];
      });
      if (previousReward.length > 0 && nextReward.length == 0) progress = 100;
      return getProgress(points: points, progress: progress);
    } else {
      return getProgress();
    }
  }

  Widget getProgress({int points = 0, double progress = 0}) {
    return Container(
      margin: EdgeInsets.all(16),
      decoration: BoxDecoration(
        color: Color(0xFFFFF6E6),
        borderRadius: BorderRadius.circular(8),
        boxShadow: [
          BoxShadow(
            color: Colors.grey.withOpacity(0.5),
            spreadRadius: 2,
            blurRadius: 5,
            offset: Offset(0, 3),
          ),
        ],
      ),
      padding: const EdgeInsets.only(
          left: 20.0, right: 20.0, top: 25.0, bottom: 25.0),
      child: Column(
        children: [
          Padding(
            padding: const EdgeInsets.only(top: 10.0, bottom: 30.0),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Text(
                  "Level ${level}",
                  style: textStyle(),
                ),
                Row(
                  children: [
                    Text(
                      widget.currentUser.score.toString() + " Points",
                      style: textStyle(),
                    ),
                    Text(
                      nextAchiveReward != null
                          ? nextAchiveReward.toString() + " Points"
                          : '',
                      style: textStyle(),
                    ),
                  ],
                ),
              ],
            ),
          ),
          LinearGradientProgressIndicator(
            value: progress,
            backgroundColor: ColorConstants.progressBgColor,
            gradientColors: [
              ColorConstants.progressGrad1Color,
              ColorConstants.progressGrad2Color,
            ],
            borderColor: ColorConstants.progressBorderColor,
          ),
          Padding(
            padding: const EdgeInsets.only(top: 8.0),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.end,
              children: [
                Expanded(
                  child: Text(
                    progress.toInt().toString() + "% completed",
                    textAlign: TextAlign.right,
                  ),
                ),
              ],
            ),
          ),
        ],
      ),
    );
  }
}
