import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:progamification/src/services/sas_token.service.dart';
import 'package:progamification/src/widgets/billing_form.dart';
import 'package:progamification/src/widgets/wallet_balance.dart';

class RedeemProduct extends StatefulWidget {
  final String userId;
  final String applicationId;
  final Object product;
  const RedeemProduct(
      {Key? key,
      required this.userId,
      required this.applicationId,
      required this.product})
      : super(key: key);

  @override
  _RedeemProductState createState() => _RedeemProductState();
}

class _RedeemProductState extends State<RedeemProduct> {
  SasTokenService sasTokenService = Get.find<SasTokenService>();
  String sasToken = "";
  @override
  void initState() {
    super.initState();
    sasTokenService.getSasToken().then((value) {
      setState(() {
        sasToken = value.toString();
      });
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(
        backgroundColor: Colors.white,
        automaticallyImplyLeading: false,
        toolbarHeight: kTextTabBarHeight,
        flexibleSpace: Get.width < 600
            ? Row(
                mainAxisAlignment: MainAxisAlignment.start,
                crossAxisAlignment: CrossAxisAlignment.center,
                children: [
                  Container(
                    decoration: BoxDecoration(
                      borderRadius: BorderRadius.circular(50),
                      border: Border.all(color: Colors.grey[400]!),
                    ),
                    margin: const EdgeInsets.only(top: 45.0, left: 20),
                    child: ClipRRect(
                      borderRadius: BorderRadius.circular(30),
                      child: FloatingActionButton(
                        onPressed: (() => Navigator.pop(context)),
                        elevation: 0,
                        backgroundColor: Colors.grey[100],
                        child: const Icon(
                          Icons.arrow_back,
                          color: Colors.black,
                        ),
                      ),
                    ),
                  ),
                  Container(
                      margin: const EdgeInsets.only(top: 45.0, left: 20),
                      child: Text(
                        "Redeem",
                        style: TextStyle(
                            fontSize: 25, fontWeight: FontWeight.bold),
                      )),
                  Spacer(),
                  Padding(
                    padding: const EdgeInsets.only(right: 20.0),
                    child: WalletBalance(
                      userId: widget.userId,
                      applicationId: widget.applicationId,
                    ),
                  ),
                ],
              )
            : null,
      ),
      body: SafeArea(
        child: Column(
          children: [
            Padding(
              padding: const EdgeInsets.all(18.0),
              child: Column(
                mainAxisAlignment: MainAxisAlignment.start,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Padding(
                    padding: const EdgeInsets.all(8.0),
                    child: Image.network(
                      (widget.product
                              as Map<String, dynamic>)['productImageUrl'] +
                          sasToken,
                      width: 700,
                      height: 250,
                      fit: BoxFit.fill,
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.all(8.0),
                    child: Text(
                      (widget.product as Map<String, dynamic>)['productName']
                          .toString(),
                      style:
                          TextStyle(fontSize: 20, fontWeight: FontWeight.bold),
                    ),
                  ),
                  Container(
                    margin: const EdgeInsets.only(top: 10.0, bottom: 10.0),
                    child: Row(
                      children: [
                        sasToken.isNotEmpty
                            ? Image.network(
                                (widget.product as Map<String, dynamic>)[
                                        'virtualMoneyImageUrl'] +
                                    sasToken,
                                width: 28,
                                height: 25,
                                fit: BoxFit.cover,
                              )
                            : SizedBox(),
                        SizedBox(width: 8),
                        Text((widget.product
                                    as Map<String, dynamic>)['eligibleMoney']
                                .toString() +
                            " Coins"),
                      ],
                    ),
                  ),
                  ElevatedButton(
                    style: ButtonStyle(
                      backgroundColor:
                          MaterialStateProperty.all<Color>(Color(0xFFF5DA48)),
                    ),
                    onPressed: () {
                      Navigator.push(
                        context,
                        MaterialPageRoute(
                            builder: (context) => BillingForm(
                                  userId: widget.userId,
                                  applicationId: widget.applicationId,
                                  productId: (widget.product
                                          as Map<String, dynamic>)['id']
                                      .toString(),
                                )),
                      );
                    },
                    child: Text(
                      'Redeem Now >',
                      style: TextStyle(color: Colors.black),
                    ),
                  )
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }
}
