import 'dart:math';

import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:progamification/src/services/sas_token.service.dart';
import 'package:progamification/src/utilities/helper.dart';
import 'package:google_fonts/google_fonts.dart';

class Rewards extends StatefulWidget {
  final AsyncSnapshot<Map<String, dynamic>>? snapshot;
  const Rewards({Key? key, required this.snapshot}) : super(key: key);

  @override
  State<Rewards> createState() => _RewardsState();
}

class _RewardsState extends State<Rewards> {
  SasTokenService sasTokenService = Get.find<SasTokenService>();
  String sasToken = "";

  @override
  initState() {
    super.initState();
    sasTokenService.getSasToken().then((value) {
      setState(() {
        sasToken = value.toString();
      });
    });
  }

  TextStyle headers(fontSize) => TextStyle(
      fontSize: fontSize,
      color: Colors.black,
      fontWeight: FontWeight.w700,
      fontFamily: GoogleFonts.plusJakartaSans().fontFamily);
  @override
  Widget build(BuildContext context) {
    if (widget.snapshot!.hasData) {
      var userRewards =
          widget.snapshot!.data!['userRewards'] as Map<String, dynamic>;
      var rewardGroupNames = userRewards.keys.toList();
      return Column(children: [
        Container(
            margin: const EdgeInsets.only(
                top: 20.0, left: 20.0, right: 10.0, bottom: 20.0),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Text(
                  "Earned badges",
                  style: headers(19.0),
                ),
              ],
            )),
        SizedBox(
            child: SingleChildScrollView(
                scrollDirection: Axis.vertical,
                child: Column(
                    children: rewardGroupNames
                        .map((e) => getRewardsGroup(userRewards[e]))
                        .toList())))
      ]);
    } else {
      return const Center(
          heightFactor: 5.0, child: CircularProgressIndicator());
    }
  }

  Widget getRewardsGroup(List rewards) {
    List<Widget> cards = [];

    for (int i = 0; i < rewards.length; i++) {
      cards.add(
        Expanded(
          child: getRewardItem(
            rewards[i]['value'],
            rewards[i]['sourceImgUrl'],
            rewards[i]['attained'] as bool,
          ),
        ),
      );
      if ((i + 1) % 2 == 0 || i == rewards.length - 1) {
        cards.add(SizedBox(height: 150));
      }
    }

    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Row(
          mainAxisAlignment: MainAxisAlignment.spaceEvenly,
          children: cards,
        ),
      ],
    );
  }

  Widget getRewardItem(String title, String sourceImgUrl, bool isAttained) {
    final random = Random();
    final Color randomColor = Color.fromRGBO(
      random.nextInt(256),
      random.nextInt(256),
      random.nextInt(256),
      1,
    );
    return Align(
      alignment: Alignment.centerLeft,
      child: Padding(
        padding: const EdgeInsets.all(8.0),
        child: Container(
          width: 200,
          child: Card(
            elevation: 2.0,
            child: Padding(
              padding: const EdgeInsets.only(top: 8.0),
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Opacity(
                    opacity: isAttained ? 1.0 : 0.3,
                    child: Center(
                      child: Container(
                        width: 60,
                        height: 60,
                        margin: const EdgeInsets.only(bottom: 12.0),
                        padding: const EdgeInsets.all(3.0),
                        child: ClipOval(
                          child: CachedNetworkImage(
                            key: UniqueKey(),
                            imageUrl: sourceImgUrl + sasToken,
                            width: 60.0,
                            height: 60.0,
                            fit: BoxFit.cover,
                            placeholder: (context, url) => Image.asset(
                              "assets/icons/no-reward.png",
                              package: "progamification",
                            ),
                            errorWidget: (context, url, error) => Image.asset(
                              "assets/icons/no-reward.png",
                              package: "progamification",
                            ),
                          ),
                        ),
                      ),
                    ),
                  ),
                  Container(
                    width: double.infinity,
                    color: randomColor,
                    child: Expanded(
                      child: Center(
                        child: Padding(
                          padding: const EdgeInsets.all(8.0),
                          child: Text(
                            capitalizeFirst(title),
                            style: TextStyle(
                              color: Colors.white,
                              fontWeight: FontWeight.w600,
                              fontSize: 12,
                              fontFamily:
                                  GoogleFonts.plusJakartaSans().fontFamily,
                            ),
                          ),
                        ),
                      ),
                    ),
                  ),
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }
}
