import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:progamification/src/environments/env.dart';
import 'package:progamification/src/services/redeem.service.dart';
import 'package:progamification/src/services/sas_token.service.dart';
import 'package:progamification/src/widgets/list_order_products.dart';
import 'package:progamification/src/widgets/list_redemable_product.dart';
import 'package:progamification/src/widgets/wallet.dart';
import 'package:progamification/src/widgets/wallet_balance.dart';

class SuccessRedeem extends StatefulWidget {
  final String userId;
  final String applicationId;
  final Object productId;
  const SuccessRedeem({
    Key? key,
    required this.userId,
    required this.applicationId,
    required this.productId,
  }) : super(key: key);

  @override
  State<SuccessRedeem> createState() => _SuccessRedeemState();
}

class _SuccessRedeemState extends State<SuccessRedeem> {
  SasTokenService sasTokenService = Get.find<SasTokenService>();
  late Map<String, dynamic> userWalletBalance = {};
  String sasToken = "";
  @override
  void initState() {
    super.initState();
    sasTokenService.getSasToken().then((value) {
      setState(() {
        sasToken = value.toString();
      });
    });
    _getWalletBalance(widget.userId, widget.applicationId);
  }

  Future<void> _getWalletBalance(String userId, String appId) async {
    try {
      await Get.find<RedeemService>()
          .getWalletBalance(appId, userId)
          .then((data) async {
        setState(() {
          userWalletBalance =
              Map<String, dynamic>.from(data!.data!['balance'][0]);
        });
      });
    } catch (e) {}
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(
        backgroundColor: Colors.white,
        automaticallyImplyLeading: false,
        toolbarHeight: kTextTabBarHeight,
        flexibleSpace: Get.width < 600
            ? Row(
                crossAxisAlignment: CrossAxisAlignment.center,
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  Container(
                      margin: const EdgeInsets.only(top: 45.0, left: 20),
                      child: Text(
                        "Redeem",
                        style: TextStyle(
                            fontSize: 28, fontWeight: FontWeight.bold),
                      )),
                  Spacer(),
                  Row(
                    children: [
                      Container(
                        width: 80,
                        child: WalletBalance(
                          userId: widget.userId,
                          applicationId: widget.applicationId,
                        ),
                      ),
                      Container(
                        decoration: BoxDecoration(
                          borderRadius: BorderRadius.circular(50),
                          border: Border.all(color: Colors.grey[400]!),
                        ),
                        margin: const EdgeInsets.only(
                            top: 45.0, left: 20, right: 10),
                        child: ClipRRect(
                          borderRadius: BorderRadius.circular(30),
                          child: FloatingActionButton(
                            onPressed: () {
                              Navigator.push(
                                context,
                                MaterialPageRoute(
                                    builder: (context) => ListRedemableProduct(
                                          userId: widget.userId,
                                          applicationId: widget.applicationId,
                                        )),
                              );
                            },
                            elevation: 0,
                            backgroundColor: Colors.grey[100],
                            child: const Icon(
                              Icons.close,
                              color: Colors.black,
                            ),
                          ),
                        ),
                      ),
                    ],
                  ),
                ],
              )
            : null,
      ),
      body: SafeArea(
        child: Padding(
            padding: const EdgeInsets.only(top: 18.0, bottom: 18.0),
            child: userWalletBalance.isNotEmpty && sasToken.isNotEmpty
                ? Column(
                    mainAxisAlignment: MainAxisAlignment.center,
                    children: [
                      Image.network(blobUrl + "success.jpg"),
                      Padding(
                        padding: const EdgeInsets.only(top: 8.0, bottom: 8.0),
                        child: Text(
                          "Order placed Successfully",
                          style: TextStyle(fontSize: 18.0),
                        ),
                      ),
                      Padding(
                        padding: const EdgeInsets.only(top: 8.0, bottom: 8.0),
                        child: Text(
                          "5 coins",
                          style: TextStyle(fontSize: 15.0),
                        ),
                      ),
                      Padding(
                        padding: const EdgeInsets.only(top: 8.0, bottom: 8.0),
                        child: Text(
                            "Debited from your wallet and Your current coin balance is"),
                      ),
                      Row(
                        mainAxisAlignment: MainAxisAlignment.center,
                        crossAxisAlignment: CrossAxisAlignment.center,
                        children: [
                          Padding(
                            padding: const EdgeInsets.all(5.0),
                            child: Image.network(
                              userWalletBalance['imageUrl'] + sasToken,
                              width: 25,
                              height: 25,
                              fit: BoxFit.cover,
                            ),
                          ),
                          Text(userWalletBalance['balance'].toString() + " Coins")
                        ],
                      ),
                      Padding(
                        padding: const EdgeInsets.only(left: 18.0, right: 18.0),
                        child: Container(
                          decoration: BoxDecoration(
                            border: Border(
                              bottom: BorderSide(
                                color: const Color.fromARGB(255, 211, 205, 205),
                                width: 1.0,
                              ),
                            ),
                          ),
                        ),
                      ),
                      Padding(
                        padding: const EdgeInsets.all(18.0),
                        child: Column(
                          crossAxisAlignment: CrossAxisAlignment.stretch,
                          children: [
                            ElevatedButton(
                                onPressed: () {
                                  Navigator.push(
                                    context,
                                    MaterialPageRoute(
                                        builder: (context) => ListOrderProduct(
                                              userId: widget.userId,
                                              applicationId:
                                                  widget.applicationId,
                                            )),
                                  );
                                },
                                child: Text("Go to My Orders")),
                            ElevatedButton(
                                onPressed: () {
                                  Navigator.push(
                                    context,
                                    MaterialPageRoute(
                                        builder: (context) => Wallet(
                                              userId: widget.userId,
                                              applicationId:
                                                  widget.applicationId,
                                            )),
                                  );
                                },
                                child: Text("Go to Wallet"))
                          ],
                        ),
                      )
                    ],
                  )
                : SizedBox()),
      ),
    );
  }
}
