import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:get/get_core/src/get_main.dart';
import 'package:progamification/src/services/redeem.service.dart';
import 'package:progamification/src/widgets/list_order_products.dart';
import 'package:progamification/src/widgets/list_redemable_product.dart';
import 'package:progamification/src/widgets/wallet_balance.dart';

class Wallet extends StatefulWidget {
  final String userId;
  final String applicationId;

  const Wallet({
    Key? key,
    required this.userId,
    required this.applicationId,
  }) : super(key: key);

  @override
  _WalletState createState() => _WalletState();
}

class _WalletState extends State<Wallet> {
  late List<Map<String, dynamic>> listOrders;
  late bool isLoading;

  @override
  void initState() {
    super.initState();
    listOrders = [];
    isLoading = true;
    _getOrderHistory(widget.userId, widget.applicationId);
  }

  Future<void> _getOrderHistory(String userId, String appId) async {
    setState(() {
      isLoading = true;
    });
    try {
      await Get.find<RedeemService>()
          .getTransactionHistory(userId, appId)
          .then((data) async {
        setState(() {
          listOrders = List<Map<String, dynamic>>.from(data.data).toList();
          isLoading = false;
        });
      });
    } catch (e) {
      setState(() {
        isLoading = false;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(
        backgroundColor: Colors.white,
        automaticallyImplyLeading: false,
        toolbarHeight: kTextTabBarHeight,
        flexibleSpace: Get.width < 600
            ? Row(
                crossAxisAlignment: CrossAxisAlignment.center,
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  Container(
                      margin: const EdgeInsets.only(top: 45.0, left: 20),
                      child: Text(
                        "Wallet",
                        style: TextStyle(
                            fontSize: 28, fontWeight: FontWeight.bold),
                      )),
                  Spacer(),
                  Row(
                    children: [
                      WalletBalance(
                        userId: widget.userId,
                        applicationId: widget.applicationId,
                      ),
                      Container(
                        decoration: BoxDecoration(
                          borderRadius: BorderRadius.circular(50),
                          border: Border.all(color: Colors.grey[400]!),
                        ),
                        margin: const EdgeInsets.only(
                            top: 45.0, left: 20, right: 10),
                        child: ClipRRect(
                          borderRadius: BorderRadius.circular(30),
                          child: FloatingActionButton(
                            onPressed: (() => Navigator.pop(context)),
                            elevation: 0,
                            backgroundColor: Colors.grey[100],
                            child: const Icon(
                              Icons.close,
                              color: Colors.black,
                            ),
                          ),
                        ),
                      ),
                    ],
                  ),
                ],
              )
            : null,
      ),
      body: Container(
        child: isLoading
            ? Center(
                child: CircularProgressIndicator(),
              )
            : Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Container(
                    padding: EdgeInsets.all(20),
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.start,
                      children: [
                        Padding(
                          padding: EdgeInsets.only(right: 16),
                          child: Container(
                            child: ElevatedButton.icon(
                              onPressed: () {
                                Navigator.push(
                                  context,
                                  MaterialPageRoute(
                                      builder: (context) =>
                                          ListRedemableProduct(
                                            userId: widget.userId,
                                            applicationId: widget.applicationId,
                                          )),
                                );
                              },
                              icon: Icon(Icons.redeem),
                              label: Text(
                                "Redeem",
                                style: TextStyle(
                                    color: Color.fromARGB(248, 0, 0, 0)),
                              ),
                              style: ElevatedButton.styleFrom(
                                backgroundColor: Colors.grey[100],
                                shape: RoundedRectangleBorder(
                                  borderRadius: BorderRadius.circular(30),
                                ),
                                padding: EdgeInsets.symmetric(
                                    vertical: 10, horizontal: 20),
                              ),
                            ),
                          ),
                        ),
                        Padding(
                          padding: EdgeInsets.only(right: 16),
                          child: Container(
                            child: ElevatedButton.icon(
                              onPressed: () {
                                Navigator.push(
                                  context,
                                  MaterialPageRoute(
                                      builder: (context) => ListOrderProduct(
                                            userId: widget.userId,
                                            applicationId: widget.applicationId,
                                          )),
                                );
                              },
                              icon: Icon(Icons.shopping_cart),
                              label: Text(
                                "My Orders",
                                style: TextStyle(
                                    color: Color.fromARGB(248, 0, 0, 0)),
                              ),
                              style: ElevatedButton.styleFrom(
                                backgroundColor: Colors.grey[100],
                                shape: RoundedRectangleBorder(
                                  borderRadius: BorderRadius.circular(30),
                                ),
                                padding: EdgeInsets.symmetric(
                                    vertical: 10, horizontal: 20),
                              ),
                            ),
                          ),
                        ),
                      ],
                    ),
                  ),
                  Container(
                    margin: EdgeInsets.only(left: 22),
                    child: Column(
                      mainAxisAlignment: MainAxisAlignment.start,
                      children: [
                        Text(
                          "Transaction History",
                          style: TextStyle(
                              fontSize: 24, fontWeight: FontWeight.bold),
                        ),
                      ],
                    ),
                  ),
                  Expanded(
                    child: ListView.builder(
                      itemCount: listOrders.length,
                      itemBuilder: (context, index) {
                        final order = listOrders[index];
                        return Padding(
                          padding: EdgeInsets.symmetric(vertical: 14.0),
                          child: Container(
                            margin: EdgeInsets.only(left: 10, right: 10),
                            decoration: BoxDecoration(
                              border: Border(
                                bottom: BorderSide(
                                    color: Colors.grey[300]!, width: 1.0),
                              ),
                            ),
                            child: Padding(
                              padding: const EdgeInsets.only(bottom: 19.0),
                              child: ListTile(
                                leading: Image.network(order['productImageUrl'],
                                    width: 100, fit: BoxFit.fill),
                                title: Text(
                                  order['productName'],
                                  textAlign: TextAlign.start,
                                ),
                                trailing: Column(
                                  crossAxisAlignment: CrossAxisAlignment.start,
                                  children: [
                                    Text(
                                      "- ${order['virtualMoneyCount']} Coins",
                                      textAlign: TextAlign.start,
                                      style: TextStyle(fontSize: 15),
                                    ),
                                  ],
                                ),
                              ),
                            ),
                          ),
                        );
                      },
                    ),
                  ),
                ],
              ),
      ),
    );
  }
}
